=======
Boolean
=======

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Expr.all
    Expr.any
    Expr.is_between
    Expr.is_duplicated
    Expr.is_finite
    Expr.is_first
    Expr.is_first_distinct
    Expr.is_in
    Expr.is_infinite
    Expr.is_last
    Expr.is_last_distinct
    Expr.is_nan
    Expr.is_not
    Expr.is_not_nan
    Expr.is_not_null
    Expr.is_null
    Expr.is_unique
    Expr.not_
